==> camel-k-model-v1-6.1.0-sources.jar: io/fabric8/camelk/v1/FailureRecoveryFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class FailureRecoveryFluentImpl<A extends FailureRecoveryFluent<A>> extends BaseFluent<A> implements FailureRecoveryFluent<A>{
  public FailureRecoveryFluentImpl() {
  }
  public FailureRecoveryFluentImpl(FailureRecovery instance) {
    this.withAttempt(instance.getAttempt()); 
    this.withAttemptMax(instance.getAttemptMax()); 
    this.withAttemptTime(instance.getAttemptTime()); 
  }
  private Integer attempt;
  private Integer attemptMax;
  private String attemptTime;
  public Integer getAttempt() {
    return this.attempt;
  }
  public A withAttempt(Integer attempt) {
    this.attempt=attempt; return (A) this;
  }
  public Boolean hasAttempt() {
    return this.attempt != null;
  }
  public Integer getAttemptMax() {
    return this.attemptMax;
  }
  public A withAttemptMax(Integer attemptMax) {
    this.attemptMax=attemptMax; return (A) this;
  }
  public Boolean hasAttemptMax() {
    return this.attemptMax != null;
  }
  public String getAttemptTime() {
    return this.attemptTime;
  }
  public A withAttemptTime(String attemptTime) {
    this.attemptTime=attemptTime; return (A) this;
  }
  public Boolean hasAttemptTime() {
    return this.attemptTime != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    FailureRecoveryFluentImpl that = (FailureRecoveryFluentImpl) o;
    if (attempt != null ? !attempt.equals(that.attempt) :that.attempt != null) return false;
    if (attemptMax != null ? !attemptMax.equals(that.attemptMax) :that.attemptMax != null) return false;
    if (attemptTime != null ? !attemptTime.equals(that.attemptTime) :that.attemptTime != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(attempt,  attemptMax,  attemptTime,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (attempt != null) { sb.append("attempt:"); sb.append(attempt + ","); }
    if (attemptMax != null) { sb.append("attemptMax:"); sb.append(attemptMax + ","); }
    if (attemptTime != null) { sb.append("attemptTime:"); sb.append(attemptTime); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/FailureRecoveryFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class FailureRecoveryFluentImpl<A extends FailureRecoveryFluent<A>> extends BaseFluent<A> implements FailureRecoveryFluent<A>{
  public FailureRecoveryFluentImpl() {
  }
  public FailureRecoveryFluentImpl(FailureRecovery instance) {
    if (instance != null) {
      this.withAttempt(instance.getAttempt());
      this.withAttemptMax(instance.getAttemptMax());
      this.withAttemptTime(instance.getAttemptTime());
    }
  }
  private Integer attempt;
  private Integer attemptMax;
  private String attemptTime;
  public Integer getAttempt() {
    return this.attempt;
  }
  public A withAttempt(Integer attempt) {
    this.attempt=attempt; return (A) this;
  }
  public Boolean hasAttempt() {
    return this.attempt != null;
  }
  public Integer getAttemptMax() {
    return this.attemptMax;
  }
  public A withAttemptMax(Integer attemptMax) {
    this.attemptMax=attemptMax; return (A) this;
  }
  public Boolean hasAttemptMax() {
    return this.attemptMax != null;
  }
  public String getAttemptTime() {
    return this.attemptTime;
  }
  public A withAttemptTime(String attemptTime) {
    this.attemptTime=attemptTime; return (A) this;
  }
  public Boolean hasAttemptTime() {
    return this.attemptTime != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FailureRecoveryFluentImpl that = (FailureRecoveryFluentImpl) o;
    if (!java.util.Objects.equals(attempt, that.attempt)) return false;

    if (!java.util.Objects.equals(attemptMax, that.attemptMax)) return false;

    if (!java.util.Objects.equals(attemptTime, that.attemptTime)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(attempt,  attemptMax,  attemptTime,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (attempt != null) { sb.append("attempt:"); sb.append(attempt + ","); }
    if (attemptMax != null) { sb.append("attemptMax:"); sb.append(attemptMax + ","); }
    if (attemptTime != null) { sb.append("attemptTime:"); sb.append(attemptTime); }
    sb.append("}");
    return sb.toString();
  }
  
}
